@@ -23,7 +23,7 @@ Requires tcpwatch.py available at:
 
 Credits goes to Ian Bicking for parsing tcpwatch files.
 
-$Id: Recorder.py 33463 2006-02-24 14:09:21Z bdelbosc $
+$Id: Recorder.py 52553 2008-02-11 21:43:38Z bdelbosc $
 """
 import os
 import sys
@@ -60,15 +60,21 @@ class Request:
 
     def extractParam(self):
         """Turn muti part encoded form into params."""
-        environ = {
-            'CONTENT_TYPE': self.headers['content-type'],
-            'CONTENT_LENGTH': self.headers['content-length'],
-            'REQUEST_METHOD': 'POST',
-            }
+        params = []
+        try:
+            environ = {
+                'CONTENT_TYPE': self.headers['content-type'],
+                'CONTENT_LENGTH': self.headers['content-length'],
+                'REQUEST_METHOD': 'POST',
+                }
+        except KeyError:
+            trace('# Warning: missing header content-type or content-length'
+                  ' in file: %s not an http request ?\n' % self.file_path)
+            return params
+
         form = FieldStorage(fp=StringIO(self.body),
                             environ=environ,
                             keep_blank_values=True)
-        params = []
         try:
             keys = form.keys()
         except TypeError:
@@ -133,6 +139,8 @@ class Response:
 
 class RecorderProgram:
     """A tcpwatch to funkload recorder."""
+    MYFACES_STATE = 'org.apache.myfaces.trinidad.faces.STATE'
+    MYFACES_FORM = 'org.apache.myfaces.trinidad.faces.FORM'
     USAGE = """%prog [options] [test_name]
 
 %prog launch a TCPWatch proxy and record activities, then output
@@ -167,6 +175,7 @@ Examples
         self.test_name = None
         self.script_path = None
         self.configuration_path = None
+        self.use_myfaces = False
         self.parseArgs(argv)
 
     def parseArgs(self, argv):
@@ -203,10 +212,11 @@ Examples
         self.tcpwatch_path = mkdtemp('_funkload')
         cmd = 'tcpwatch.py -p %s -s -r %s' % (self.port,
                                               self.tcpwatch_path)
-        if self.verbose:
-            cmd += ' | grep "T http"'
-        else:
-            cmd += ' > /dev/null'
+        if os.name == 'posix':
+            if self.verbose:
+                cmd += ' | grep "T http"'
+            else:
+                cmd += ' > /dev/null'
         trace("Hit Ctrl-C to stop recording.\n")
         os.system(cmd)
 
@@ -272,11 +282,27 @@ Examples
                                           request.url))
         else:
             text.append('self.%s(server_url + "%s"' % (
-                request.method.lower(),  request.rurl))
+                request.method.lower(),  request.rurl.strip()))
         description = "%s %s" % (request.method.capitalize(),
                                  request.path | truncate(42))
         if request.body:
-            params = ('params=%s' % request.extractParam())
+            params = request.extractParam()
+            myfaces_form = None
+            if self.MYFACES_STATE not in [key for key, value in params]:
+                params = 'params=%s' % params
+            else:
+                # apache myfaces state add a wrapper
+                self.use_myfaces = True
+                new_params = []
+                for key, value in params:
+                    if key == self.MYFACES_STATE:
+                        continue
+                    if key == self.MYFACES_FORM:
+                        myfaces_form = value
+                        continue
+                    new_params.append([key, value])
+                params = "    self.myfacesParams(%s, form='%s')" % (new_params,
+                                                                    myfaces_form)
             params = re.sub("'Upload\(([^\)]*)\)'", "Upload(\\1)", params)
             text.append(', ' + params)
         text.append(', description="%s")' % description)
@@ -298,7 +324,11 @@ Examples
         """Write the FunkLoad test script."""
         trace('Creating script: %s.\n' % self.script_path)
         from pkg_resources import resource_string
-        tpl = resource_string('funkload', 'data/ScriptTestCase.tpl')
+        if self.use_myfaces:
+            tpl_name = 'data/MyFacesScriptTestCase.tpl'
+        else:
+            tpl_name = 'data/ScriptTestCase.tpl'
+        tpl = resource_string('funkload', tpl_name)
         content = tpl % {'script': script,
                          'test_name': self.test_name,
                          'class_name': self.class_name}
